#
# spec file for package uranium-lulzbot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define pythons 311

Name:           uranium-lulzbot
Conflicts:      uranium
Version:        3.6.21
Release:        bp160.1.6
Summary:        3D printer control software: python UI stack
License:        AGPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://code.alephobjects.com/diffusion/U/uranium.git
Source0:        Uranium-%{version}.tar.xz
Patch1:         fix-build.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  python311-devel
Recommends:     python311-numpy-stl

%description
Cura is an engine for processing 3D models
into 3D printing instruction for Ultimaker and other GCode based 3D printers.
It is part of the larger open source project called "Cura".

Uranium is the Python framework for the Cura UI.

%prep
%autosetup -p1 -n Uranium-%version

%build
CFLAGS="%{optflags}"
export CFLAGS
%cmake -DPYTHON_EXECUTABLE=/usr/bin/python3.11
make %{?_smp_mflags}

%install
%if 0%{?suse_version}
pushd build
%make_install
popd
%else
# Fedora
%make_install
%endif
# uranium uses i18n instead of locale for the path to translation files,
# thus we cannot use %%find_lang
find %{buildroot}%{_datadir}/uranium -name uranium.po* -delete
echo '%defattr(644,root,root,755)' > %{name}.lang
find %{buildroot}%{_datadir}/uranium -name uranium.mo | sed '
  s:'%{buildroot}'::; s:\(.*/i18n/\)\([^/]\+\)\(.*mo\):%lang(\2) \1\2\3:' \
  >> %{name}.lang
find %{buildroot}%{_datadir}/uranium -type d -path \*i18n\* | sed '
  s:'%{buildroot}'::; s:\(.*/i18n.*\):%dir \1:' \
  >> %{name}.lang
# fix cmake install dir
mv %{buildroot}/%{_datadir}/cmake* %{buildroot}/%{_datadir}/cmake

%files -f %{name}.lang
%doc docs README.md
%license LICENSE
/usr/lib/python3.11/site-packages/UM
%{_prefix}/lib/uranium
%dir %{_datadir}/uranium
%{_datadir}/uranium/resources
%{_datadir}/cmake

%changelog
* Wed Feb 21 2024 Adrian Schröter <adrian@suse.de>
- switch to python 3.11
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Sep 26 2023 Adrian Schröter <adrian@suse.de>
- switch to python3.10
* Mon Jun 27 2022 Adrian Schröter <adrian@suse.de>
- fix runtime crashes with python 3.10
* Fri Oct 11 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.21
  * no changes except version
- fix_qt5.12.patch became obsolete
* Mon Oct  7 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.20
  * no changes except version
* Thu Sep  5 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.19
  * no changes except version
* Mon Aug 12 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.18
  * no changes except version
* Mon Jul  8 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.13
  * no changes except version
* Tue Jun 25 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.10
  * minor crash fixes
* Mon May 27 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.9
  * no changes except version
* Mon May  6 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.8
  * no changes except version
* Wed May  1 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.7
  * no changes except version
* Thu Apr 18 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.6
  * no changes except version
* Fri Apr  5 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.5
  * no changes except version
* Wed Feb 20 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.4
* Thu Jan 17 2019 Adrian Schröter <adrian@suse.de>
- add recommends to numpy-stl
* Tue Jan 15 2019 Adrian Schröter <adrian@suse.de>
- add fix_qt5.12.patch to fix i18n text string handling in qml
  with Qt 5.12
* Wed Jan  9 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.1
  https://code.alephobjects.com/w/cura-lulzbot/
* Tue Nov 20 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.2.32
  * minor code cleanup
* Mon Oct 22 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.2.29
  * version increase only
* Tue Sep 25 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.2.28
  * fixing rotation and duplicate model selection
* Mon Aug  6 2018 adrian@suse.de
- update to version 3.2.24
  * rotate tool updates
* Fri Jul 13 2018 adrian@suse.de
- disable debug logging by default
* Fri Jul 13 2018 adrian@suse.de
- update to version 3.2.23
  * version increase only
* Tue Jul  3 2018 adrian@suse.de
- update to version 3.2.22
  * Bottom view orientation button added
* Wed May 30 2018 adrian@suse.de
- update to version 3.2.21
  * version increase only
* Mon May 14 2018 adrian@suse.de
- update to version 3.2.20
  * version increase only
* Wed May  2 2018 adrian@suse.de
- update to version 3.2.19
  * version increase only
* Mon Mar 26 2018 adrian@suse.de
- update to version 3.2.18
  * version increase only
* Thu Mar  8 2018 adrian@suse.de
- update to version 3.2.9
  * version increase only
* Sat Feb 10 2018 jengelh@inai.de
- Trim filler words from description.
* Wed Jan 31 2018 jengelh@inai.de
- Fix RPM group.
* Wed Jan 31 2018 adrian@suse.de
- update to version 3.2.1
* Wed Jan  3 2018 adrian@suse.de
- update to 2.6.63
* Fri Nov  3 2017 adrian@suse.de
- update to 2.6.43
* Mon Sep  4 2017 adrian@suse.de
- update to 2.6.23
* Mon Jun 26 2017 adrian@suse.de
- stable 2.6.0
* Mon Jun 20 2016 adrian@suse.de
- initial package
